__name__ = "orix"
__version__ = "0.9.0.post0"
__author__ = "orix developers"
__author_email__ = "pyxem.team@gmail.com"
__description__ = "orix is an open-source Python library for handling crystal orientation mapping data."
# Sorted by line contributions (ideally excluding lines in notebook files)
__credits__ = [
    "Håkon Wiik Ånes",
    "Ben Martineau",
    "Phillip Crout",
    "Paddy Harrison",
    "Duncan Johnstone",
    "Niels Cautaerts",
    "Simon Høgås",
]
